"""
URL configuration for backend project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from rest_framework import permissions
from drf_yasg.views import get_schema_view
from drf_yasg import openapi
from django.contrib import admin
from django.urls import path, include


schema_view = get_schema_view(
    openapi.Info(
        title="c3buttons",
        default_version='1.0.0',
        description="Swagger Documentation for c3buttons",
        # terms_of_service="https://link.to.something",
        contact=openapi.Contact(name="fejao", email="dont@bug.me"),
        license=openapi.License(name="MIT"),
    ),
    ### AUTH
    public=False,
    permission_classes=(permissions.IsAuthenticated,),

)


urlpatterns = [
    path("admin/", admin.site.urls),
    ###
    ### SWAGGER
    ###
    path('swagger/', schema_view.with_ui('swagger', cache_timeout=0), name='schema-swagger-ui'),
    path('swagger.json/', schema_view.without_ui(cache_timeout=0), name='schema-json'),
    ###
    ### APPS
    ###
    path('auth/', include('api_auth.urls')),
    # path("api/box/", include("api.urls")),
    path("api/", include("api.urls")),
    path("api-admin/", include("api_admin.urls")),
]
