"""
    Serializers for the models shared among this django.
"""

from django.db import models


class ButtonBox(models.Model):
    """The model for storing the information about the button box.
    """
    name = models.CharField(max_length=40, unique=True)
    # pin_number = models.PositiveIntegerField(unique=True)
    pin_button = models.PositiveIntegerField(unique=True)
    pin_led = models.PositiveIntegerField(unique=True)

    class Meta:
        """ Meta class for the Button Box model.
        Used for setting the name ot the table at the DB.
        """
        db_table = "button_box"

    def __str__(self):
        """Override from the default __str__ method for returning the name of the box instead of it's ID.
        """
        return str(self.name)


class ButtonBoxUse(models.Model):
    """The model for storing the information about the button box uses.
    """

    box_used = models.ForeignKey(
        ButtonBox,
        on_delete=models.CASCADE,
    )
    date = models.DateTimeField(auto_now_add=True, blank=True)

    class Meta:
        """ Meta class for the Button Box Use model.
        Used for setting the name ot the table at the DB.
        """
        db_table = "button_box_use"

    @property
    def box_name(self):
        """Property method for fetching the name of the box for the box used.
        """
        box_obj = ButtonBox.objects.get(name=self.box_used)
        return box_obj.name
